<?php
abstract class Akrabat_Config_Abstract
{
    protected $_config;

    /**
     * Load the section $section from the ini file called $filename. If
     * $section is null, then the entire file is loaded.
     *
     * If any keys with $section are called "include", then the section
     * pointed to by the "include" is then included first. Thus, the keys
     * in $section will override any keys of the same name in the sections
     * that have been "include"ed.
     *
     * If any key includes a ".", then this will act as a separator to create
     * a sub-array.
     *
     * example ini file:
     *      [all]
     *      db.connection = database
     *      hostname = live
     *
     *      [staging]
     *      include = all
     *      hostname = staging
     *
     * after calling $config = new Akrabat_Config($file, 'staging'); then
     *      $config->hostname = staging
     *      $config->db['connection'] = database
     *
     *
     * @param string $filename
     * @param string $section
     */
    function __construct($filename=null, $section=null)
    {
        $this->_config = array();
        if (!is_null($filename)) {
            $this->load($filename, $section);
        }
    }

    /**
     * Load a config file, overwriting any duplicate keys.
     * If $section is null, then the entire file is loaded.
     *
     * @param string $filename
     * @param string $section
     */
    abstract public function load($filename, $section=null);

    /**
     * @param string $name
     * @param mixed $default
     * @return mixed
     */
    public function get($name, $default=false)
    {
        $result = $default;
        if (isset($this->_config[$name])) {
            $result = $this->_config[$name];
        }
        return $result;
    }

    /**
     * magic function so that $config->value will work.
     *
     * @param string $name
     * @return mixed
     */
    public function __get($name)
    {
        return $this->get($name);
    }

    /**
     * This is a read only class... throw an exception on
     * setting a key!
     *
     * @param string $name
     * @param mixed $value
     */
    public function __set($name, $value)
    {
        throw new Exception('Akrabat_Config is read only!');
    }

    /**
     * Does the config key $name exist?
     *
     * @param string $name
     * @return boolean
     */
    public function exists($name)
    {
        return isset($this->_config[$name]);
    }

}
?>